@@ -1,9 +1,9 @@
 "randomForest.formula" <-
-    function(x, data = NULL, ..., subset, na.action = na.fail) {	
+    function(formula, data = NULL, ..., subset, na.action = na.fail) {	
 ### formula interface for randomForest.
 ### code gratefully stolen from svm.formula (package e1071).
 ###
-    if (!inherits(x, "formula"))
+    if (!inherits(formula, "formula"))
         stop("method is only for formula objects")
     call <- match.call()
     m <- match.call(expand = FALSE)
@@ -21,7 +21,7 @@
     for (i in seq(along=ncol(m))) {
         if(is.ordered(m[[i]])) m[[i]] <- as.numeric(m[[i]])
     }
-    ret <- randomForest.default(m, y, ...)
+    ret <- randomForest(m, y, ...)
     cl <- match.call()
     cl[[1]] <- as.name("randomForest")
     ret$call <- cl
